#!/bin/bash
#
# Script from Andrwe Lord Weber Modified by ShelbyGT500 for Copfilter
# Version: 3rdP_party_rules-2013-01beta3 - 10 janvier 2013
#                  
# This script downloads, converts and installs
# AdblockPlus lists into Privoxy
#

#######################################################################
#
#                  script variables and functions
#
######################################################################
#
# privoxy config dir (default: /etc/privoxy/)
CONFDIR=/var/log/copfilter/default/opt/privoxy/etc
# directory for temporary files
TMPDIR=/tmp/privoxy-blocklist
TMPNAME=$(basename ${0})

######################################################################
#
#                
#
######################################################################

function usage()
{
	echo "${TMPNAME} is a script to convert AdBlockPlus-lists into Privoxy-lists and install them."
	echo " "
	echo "Options:"
	echo "      -h:    Show this help."
	echo "      -q:    Don't give any output."
	echo "      -v 1:  Enable verbosity 1. Show a little bit more output."
	echo "      -v 2:  Enable verbosity 2. Show a lot more output."
	echo "      -v 3:  Enable verbosity 3. Show all possible output and don't delete temporary files.(For debugging only!!)"
	echo "      -r:    Remove all lists build by this script."
}

[ ${UID} -ne 0 ] && echo -e "Root privileges needed. Exit.\n\n" && usage && exit 1

# check whether an instance is already running
[ -e ${TMPDIR}/${TMPNAME}.lock ] && echo "An Instance of ${TMPNAME} is already running. Exit" && exit

DBG=0

function debug()
{
	[ ${DBG} -ge ${2} ] && echo -e "${1}"
}

function main()
{



	################################################################################################################
	######################################### LAST VERSION ###########################################################
	URLS=("http://shelby.eurowireless.de/LASTVERSION" )

	for url in ${URLS[@]}
	do
		file=${TMPDIR}/$(basename ${url})
		rm -f "/var/log/copfilter/default/opt/privoxy/var/log/privoxy/LASTVERSION" >/dev/null 2>&1
		wget -t 3 --no-check-certificate -O /var/log/copfilter/default/opt/privoxy/var/log/privoxy/LASTVERSION ${url} 
	done



	################################################################################################################
	######################################### FANBOY LIST ###########################################################
	URLS=("http://www.fanboy.co.nz/adblock/opera/complete/urlfilter.ini" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=fanboy.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Fanboy} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}

		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi
	

		debug "... ${actionfile} installed successfully.\n" 0
	done




	##########################################################################################
	##########################       FANBOY SOCIAL LIST       ###############################################
	########################################################################################################	
	################### download list                          #############################################
	URLS=("https://easylist-downloads.adblockplus.org/fanboy-social.txt")

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=fanboysocial.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Fanboysocial} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}


		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi	

		debug "... ${actionfile} installed successfully.\n" 0
	done

	####################################################################################################################################
	#########################################  MALWARE DOMAINS  ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/malwaredomains_full.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=malwaredomains.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{Malwaredomains} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi
	

		debug "... ${actionfile} installed successfully.\n" 0
	done



	####################################################################################################################################
	#########################################  PETER LOWE LIST  ###########################################################
	URLS=("http://pgl.yoyo.org/adservers/serverlist.php?hostformat=adblockplus;showintro=0" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=peter_lowe.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{PeterLowelist} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi
	

		debug "... ${actionfile} installed successfully.\n" 0
	done



	####################################################################################################################################
	#########################################  hpHosts LIST  ###########################################################
	URLS=("http://hosts-file.net/download/hosts.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=HpHosts.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{HpHostslist} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		

		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done


	####################################################################################################################################
	#########################################  MalwareDomainList  ###########################################################
	URLS=("http://www.malwaredomainlist.com/hostslist/hosts.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=malwaredomainlist.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Malwaredomainlist} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done


	###################################################################################################################################
	#########################################  Easylist ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/easylist.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=easylist.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Easylist} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done




	###################################################################################################################################
	#########################################  EasyPrivacy ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/easyprivacy.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=easyprivacy.script.action
		list=$(basename ${file%\.*})
		echo -e "{ +block{Easylist} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		

		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done


	###################################################################################################################################
	#########################################  Easylist GERMANY  ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/easylistgermany.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=easylistgermany.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{Easylist Germany} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done



	###################################################################################################################################
	#########################################  Easylist FRANCE + EASY PRIVACY  ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/liste_fr+easylist.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=easylistFR.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{EasylistFR} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done




	###################################################################################################################################
	#########################################  Malc0de List  ##########################################################################
	URLS=("http://malc0de.com/bl/BOOT" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=Malc0de.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{Malc0de} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done



	###################################################################################################################################
	#########################################  Easylist ITALY              ###########################################################
	URLS=("https://easylist-downloads.adblockplus.org/easylistitaly.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=easylistIT.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{EasylistIT} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done


	###################################################################################################################################
	#########################################  OPEN BL List  ##########################################################################
	URLS=("http://www.openbl.org/lists/base_180days.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=openBL.script.action
		list=$(basename ${file%\.*})


		echo -e "{ +block{OpenBL} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		

		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done




	###################################################################################################################################
	#########################################  Adversity List              ###########################################################
	URLS=("https://adversity.googlecode.com/hg/Adversity.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=Adversity.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Adversity} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		
		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done



	###################################################################################################################################
	#########################################  Antisocial              ###########################################################
	URLS=("https://adversity.googlecode.com/hg/Antisocial.txt" )

	for url in ${URLS[@]}
	do
		debug "Processing ${url} ...\n" 0
		file=${TMPDIR}/$(basename ${url})
		actionfile=Antisocial.script.action
		list=$(basename ${file%\.*})

		echo -e "{ +block{Antisocial} }" > ${TMPDIR}/${actionfile}
		cp ${TMPDIR}/${actionfile} ${CONFDIR}
		


		if [ "$(grep $(basename ${actionfile}) ${CONFDIR}/config)" == "" ] 
		then
			debug "\nModifying ${CONFDIR}/config ..." 0
			sed "s/^actionsfile user\.action/actionsfile $(basename ${actionfile})\nactionsfile user.action/" ${CONFDIR}/config > ${TMPDIR}/config
			debug "... modification done.\n" 0
			debug "Installing new config ..." 0
			cp ${TMPDIR}/config ${CONFDIR}
			debug "... installation done\n" 0
		fi

		debug "... ${actionfile} installed successfully.\n" 0
	done

}

# create temporary directory and lock file
mkdir -p ${TMPDIR}
touch ${TMPDIR}/${TMPNAME}.lock

# set command to be run on exit
[ ${DBG} -le 2 ] && trap "rm -fr ${TMPDIR};exit" INT TERM EXIT

# loop for options
while getopts ":hrqv:" opt
do
	case "${opt}" in 
		"h")
			usage
			exit 0
			;;
		"v")
			DBG="${OPTARG}"
			;;
		"q")
			DBG=-1
			;;
		"r")
#			echo "Do you really want to remove all build lists?(y/N)"
#			read choice
#			[ "${choice}" != "y" ] && exit 0
			rm -rf ${CONFDIR}/*.script.{action,filter} && \
			sed '/^actionsfile .*\.script\.action$/d;/^filterfile .*\.script\.filter$/d' -i ${CONFDIR}/config && \
			echo "Lists removed." && exit 0
			echo -e "An error occured while removing the lists.\nPlease have a look into ${CONFDIR} whether there are .script.* files and search for *.script.* in ${CONFDIR}/config."
			exit 1
			;;
		":")
			echo "${TMPNAME}: -${OPTARG} requires an argument" >&2
			exit 1
			;;
	esac
	
done

debug "URL-List: ${URLS}\nPrivoxy-Configdir: ${CONFDIR}\nTemporary directory: ${TMPDIR}" 2
main

chown -R privoxy:privoxy /var/log/copfilter/default/opt/privoxy

# restore default exit command
trap - INT TERM EXIT
[ ${DBG} -lt 2 ] && rm -r ${TMPDIR}
[ ${DBG} -eq 2 ] && rm -vr ${TMPDIR}
exit 0
